@@ -103,7 +103,9 @@ def process(smpp_client, queue):
                                 msisdn.startswith("34")
                                 or msisdn.startswith("39")
                             ):
-                                pass
+                                LOGS.logger.error(
+                                    "Erreur envoie sms {}".format(msisdn)
+                                    )
                             else:
                                 smpp_client.send_sms(
                                     msisdn,
