@@ -129,57 +129,60 @@ class Client(object):
         """le status du sms dans une tabel"""
         # msisdn_source = pdu.destination_addr.decode("utf-8")
         msisdn_dest = pdu.source_addr.decode("utf-8")
-        res = pdu.short_message.decode("utf-8")
-        res = res.replace('submit date', 'submit_date')
-        res = res.replace('done date', 'done_date')
-        res = res.split(' ')
-        infos = {
-            'date': datetime.now().strftime('%d-%m-%Y %H:%M:%S'),
-            'msisdn': msisdn_dest,
-            'submit': True
-            }
-        for x in res:
-            val = x.split(':')
-            infos.update({val[0]: val[1]})
-        cond = (
-            infos['msisdn'] is not None
-            or infos['msisdn'] != 'None'
-            )
-        if cond:
-            LOGS.logger.info(cond)
-            kwargs = {
-                'engine': self.db_engine,
-                'user': self.db_user,
-                'password': self.db_password,
-                'host': self.db_host,
-                'port': self.db_port,
-                'name': self.db_name
+        if msisdn_dest.startswith("34") or msisdn_dest.startswith("39"):
+            LOGS.logger.info("Erreur Update {}".format(msisdn_dest))
+        else:
+            res = pdu.short_message.decode("utf-8")
+            res = res.replace('submit date', 'submit_date')
+            res = res.replace('done date', 'done_date')
+            res = res.split(' ')
+            infos = {
+                'date': datetime.now().strftime('%d-%m-%Y %H:%M:%S'),
+                'msisdn': msisdn_dest,
+                'submit': True
                 }
-            url = self.database_url(**kwargs)
-            with records.Database(url) as db:
-                sql = (
-                    "UPDATE get_delivery_sms SET done_date=:done_date, "
-                    "status=:status, code=:code WHERE msisdn=:msisdn "
-                    "AND code=:err_code AND message_id=:message_id"
-                    )
-                LOGS.logger.info(sql)
-                db.query(
-                    sql,
-                    message_id=infos['id'][1:],
-                    done_date=infos['done_date'].strip(),
-                    status=infos['stat'],
-                    code=infos['err'],
-                    err_code='111',
-                    msisdn=msisdn_dest[-9:]
-                    )
-            msg = '<<< msg_id={} status={} msisdn={} code={}'.format(
-                infos['id'][1:],
-                infos['stat'],
-                msisdn_dest,
-                infos['err']
+            for x in res:
+                val = x.split(':')
+                infos.update({val[0]: val[1]})
+            cond = (
+                infos['msisdn'] is not None
+                or infos['msisdn'] != 'None'
                 )
-            journal.send(msg, REQUEST_ID=self.request_id)
-            LOGS.logger.info(infos)
+            if cond:
+                LOGS.logger.info(cond)
+                kwargs = {
+                    'engine': self.db_engine,
+                    'user': self.db_user,
+                    'password': self.db_password,
+                    'host': self.db_host,
+                    'port': self.db_port,
+                    'name': self.db_name
+                    }
+                url = self.database_url(**kwargs)
+                with records.Database(url) as db:
+                    sql = (
+                        "UPDATE get_delivery_sms SET done_date=:done_date, "
+                        "status=:status, code=:code WHERE msisdn=:msisdn "
+                        "AND code=:err_code AND message_id=:message_id"
+                        )
+                    LOGS.logger.info(sql)
+                    db.query(
+                        sql,
+                        message_id=infos['id'][1:],
+                        done_date=infos['done_date'].strip(),
+                        status=infos['stat'],
+                        code=infos['err'],
+                        err_code='111',
+                        msisdn=msisdn_dest[-9:]
+                        )
+                msg = '<<< msg_id={} status={} msisdn={} code={}'.format(
+                    infos['id'][1:],
+                    infos['stat'],
+                    msisdn_dest,
+                    infos['err']
+                    )
+                journal.send(msg, REQUEST_ID=self.request_id)
+                LOGS.logger.info(infos)
 
     def send_sms(self, msisdn, message, simulate=False, **kwargs):
         """Envoi du SMS au SMSC"""
@@ -201,8 +204,6 @@ class Client(object):
                 destination = '261{}'.format(msisdn[-9:])
             else:
                 destination = msisdn
-            journal.send("intl {}".format(destination))
-            journal.send("<<<<< kwargs {}".format(kwargs))
             parts, encoding_flag, msg_type_flag = smpplib.gsm.make_parts(
                 message
                 )
